%global pluginversion 1.0.0

Name:		scidavis
Version:	2.3.0
Release:	%mkrel 1
Summary:	An application for Scientific Data Analysis and Visualization
License:	GPLv3+
Group:		Sciences/Other
Url:		http://scidavis.sourceforge.net/
Source0:	https://github.com/highperformancecoder/scidavis/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:	desktop-file-utils
BuildRequires:	doxygen
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(muparser)
BuildRequires:	pkgconfig(gsl)
BuildRequires:	pkgconfig(egl)
BuildRequires:	pkgconfig(qwt5-qt5)
BuildRequires:	python3-qt5-devel
BuildRequires:  qtbase5-devel
BuildRequires:  devel(qwtplot3d-qt5)
BuildRequires:  python3-pyqt5-sip
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  qtlinguisttools5-devel
BuildRequires:  python3-sip-devel
Requires: python3-qt5
Recommends:     python3-%{name}

%description
SciDAVis is a free interactive application aimed at data analysis and
publication-quality plotting. It combines a shallow learning curve and
an intuitive, easy-to-use graphical user interface with powerful
features such as scriptability and extensibility.


%package -n python3-%{name}
BuildRequires:  python3-devel
BuildRequires:  python3-qt5-devel
 
Summary:        Python 3 bindings for SciDAVis
Requires:       %{name}%{?_isa} = %{version}-%{release}
Obsoletes:      python2-%{name} < 1.23-5
 
%description -n python3-%{name}
This module provides SciDAVis bindings to the Python3 programming language.

%files
%doc ChangeLog.md README.md gpl.txt scidavis.css manual/
%doc scidavis-logo.png scidavis-logo.svg
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_iconsdir}/locolor/*/apps/%{name}.png
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man1/%{name}.1*

%files -n python3-%{name}
%{python3_sitearch}/%{name}/


#-------------------------------------------------------------------------

%prep
%autosetup
# Set the correct python paths
sed -i 's+pythonconfig.path = "$$INSTALLBASE/../etc"+pythonconfig.path = "$$INSTALLBASE/..%{python3_sitearch}/scidavis"+g' config.pri
sed -i 's+pythonutils.path = "$$INSTALLBASE/share/scidavis"+pythonutils.path = "$$INSTALLBASE/..%{python3_sitearch}/scidavis"+g' config.pri

%build
# Set python version to 3
export PYTHON=python3

%qmake_qt5 \
	%if "%{_lib}" != "lib"
		libsuff=64 \
	%endif
		PRESET=linux_package \
		CONFIG+=python

%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}

# translations
install -d %{buildroot}%{_datadir}/%{name}/translations
install -D -m644 %{name}/translations/*.qm %{buildroot}%{_datadir}/%{name}/translations/

# KDE3 remnant - upstream is aware
rm -rf %{buildroot}%{_datadir}/mimelnk/

# fix desktop file
desktop-file-install \
       %{buildroot}%{_datadir}/applications/%{name}.desktop

# Plugins are unversioned .so files
cd %{buildroot}%{_libdir}/%{name}/plugins
for plugin in `ls *.so`
do
    mv ${plugin}.%{pluginversion} ${plugin}
    rm -f ${plugin}.*
done



%changelog
* Sat Jan 02 2021 joequant <joequant> 2.3.0-1.mga8
+ Revision: 1668145
- fix deps
- update to 2.3.0

* Tue Feb 18 2020 umeabot <umeabot> 1.26-2.mga8
+ Revision: 1541250
- Mageia 8 Mass Rebuild

* Sat Dec 21 2019 daviddavid <daviddavid> 1.26-1.mga8
+ Revision: 1469350
- new version: 1.26

* Thu Sep 26 2019 daviddavid <daviddavid> 1.25.1-3.mga8
+ Revision: 1446183
- rebuild for python3.8

* Tue Aug 27 2019 daviddavid <daviddavid> 1.25.1-2.mga8
+ Revision: 1433779
- rebuild for new gsl 2.6

* Mon Aug 26 2019 daviddavid <daviddavid> 1.25.1-1.mga8
+ Revision: 1432266
- new version: 1.25.1

* Tue Mar 05 2019 daviddavid <daviddavid> 1.25-1.mga7
+ Revision: 1371606
- new version: 1.25

* Sat Mar 02 2019 daviddavid <daviddavid> 1.24-1.mga7
+ Revision: 1371070
- new version: 1.24

* Tue Jan 08 2019 daviddavid <daviddavid> 1.23.4-2.mga7
+ Revision: 1352849
- rebuild for new Python 3.7

* Sun Nov 25 2018 daviddavid <daviddavid> 1.23.4-1.mga7
+ Revision: 1333951
- new version: 1.23.4
- switch to python 3
- rename and rediff set_python_path patch
- remove merged upstream patches

* Sun Sep 23 2018 umeabot <umeabot> 1.23-4.mga7
+ Revision: 1300942
- Mageia 7 Mass Rebuild

* Sun Jul 22 2018 daviddavid <daviddavid> 1.23-3.mga7
+ Revision: 1244917
- rebuild for new sip 4.19.12

* Thu Jun 07 2018 daviddavid <daviddavid> 1.23-2.mga7
+ Revision: 1235116
- fix a crash caused by Qt color picker - patch by Miquel Garriga

* Wed Jun 06 2018 daviddavid <daviddavid> 1.23-1.mga7
+ Revision: 1234931
- new version: 1.23
- remove merged upstream patch

* Wed Dec 27 2017 wally <wally> 1.22-2.mga7
+ Revision: 1185653
- rebuild for new gsl

* Sat Oct 28 2017 daviddavid <daviddavid> 1.22-1.mga7
+ Revision: 1174366
- new version: 1.22

* Tue Jan 26 2016 luigiwalser <luigiwalser> 0.2.4-16.mga6
+ Revision: 927774
- add patch to fix build with gsl version 2
- rebuild for gsl

* Fri Oct 23 2015 daviddavid <daviddavid> 0.2.4-15.mga6
+ Revision: 894408
- add more docs to fix build with latest rpm

* Wed Aug 26 2015 cjw <cjw> 0.2.4-14.mga6
+ Revision: 870065
- rebuild with gcc 5

* Wed Jan 07 2015 alexl <alexl> 0.2.4-13.mga5
+ Revision: 809167
- added GenericName in desktop file

* Wed Oct 15 2014 umeabot <umeabot> 0.2.4-12.mga5
+ Revision: 747294
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.2.4-11.mga5
+ Revision: 689055
- Mageia 5 Mass Rebuild

* Mon Sep 15 2014 alexl <alexl> 0.2.4-10.mga5
+ Revision: 676764
- translated desktop and xml files (i18n-desktop-xml.patch)

* Fri Jun 06 2014 wally <wally> 0.2.4-9.mga5
+ Revision: 634201
- rebuild for new muparser

* Sun Jan 05 2014 danf <danf> 0.2.4-8.mga4
+ Revision: 564702
- Added protected-members.patch to fix building with gcc 4.8
- Marked the scidavisrc.py file as %%config
- License is actually GPLv2+
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 0.2.4-7.mga3
+ Revision: 381817
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 24 2012 pterjan <pterjan> 0.2.4-6.mga3
+ Revision: 334450
- Add include path and lib for QtAssistantClient
- Use qwt 5
- Add another Debian patch (removing const from something which is not)
- Partially update a patch (from Debian) to link against GLU
- Add a Debian patch for arm
+ fwang <fwang>
- update new qwt inc dir

* Thu May 12 2011 mikala <mikala> 0.2.4-4.mga1
+ Revision: 97566
- Rebuild for {U+00AB} new {U+00BB} muparser ( mga #1251)

* Mon May 02 2011 mikala <mikala> 0.2.4-3.mga1
+ Revision: 94230
- Remove BuildRoot tag
- imported package scidavis

